# Dash Cytoscape [![GitHub license](https://img.shields.io/badge/license-MIT-blue.svg)](https://github.com/plotly/DashCytoscape.jl/blob/main/LICENSE)


A Dash component library for creating interactive and customizable networks in Julia, wrapped around [Cytoscape.js](http://js.cytoscape.org/).

![usage-stylesheet-demo](https://raw.githubusercontent.com/plotly/dash-cytoscape/master/demos/images/usage-stylesheet-demo.gif)

* 🌟 [Medium Article](https://medium.com/@plotlygraphs/introducing-dash-cytoscape-ce96cac824e4)
* 📣 [Community Announcement](https://community.plotly.com/t/announcing-dash-cytoscape/19095)
* 💻 [Github Repository](https://github.com/plotly/DashCytoscape.jl)
* 📚 [User Guide](https://dash-julia-docs.herokuapp.com/cytoscape)
* 🗺 [Component Reference](https://dash-julia-docs.herokuapp.com/cytoscape/reference)
* 📺 [Webinar Recording](https://www.youtube.com/watch?v=snXcIsCMQgk)


## Documentation

The [Dash Cytoscape User Guide](https://dash.plotly.com/cytoscape/) contains everything you need to know about the library. It contains useful examples, functioning code, and is fully interactive. You can also use the [component reference](https://dash.plotly.com/cytoscape/reference/) for a complete and concise specification of the API.

To learn more about the core Dash components and how to use callbacks, view the [Dash documentation](https://dash.plotly.com/).

For supplementary information about the underlying Javascript  API, view the [Cytoscape.js documentation](http://js.cytoscape.org/).

## Contributing

Make sure that you have read and understood our [code of conduct](CODE_OF_CONDUCT.md), then head over to [CONTRIBUTING](CONTRIBUTING.md) to get started.

### Testing

Instructions on how to run [tests](CONTRIBUTING.md#tests) are given in [CONTRIBUTING.md](CONTRIBUTING.md).

## License

Dash, Cytoscape.js and Dash Cytoscape are licensed under MIT. Please view [LICENSE](LICENSE) for more details.

## Contact and Support

See https://plotly.com/dash/support for ways to get in touch.

## Acknowledgments

Huge thanks to the Cytoscape Consortium and the Cytoscape.js team for their contribution in making such a complete API for creating interactive networks. This library would not have been possible without their massive work!

The Pull Request and Issue Templates were inspired from the
[scikit-learn project](https://github.com/scikit-learn/scikit-learn).

## Gallery

### Dynamically expand elements
[Code](usage-elements.py) | [Demo](https://dash-gallery.plotly.host/cytoscape-elements)
![View usage-elements on Github](demos/images/usage-elements-demo.gif)

### Interactively update stylesheet
[Code](usage-stylesheet.py) | [Demo](https://dash-gallery.plotly.host/cytoscape-stylesheet)
![View usage-stylesheet on Github](demos/images/usage-stylesheet.gif)

### Automatically generate interactive phylogeny trees
[Code](demos/usage-phylogeny.py) | [Demo](https://dash-gallery.plotly.host/cytoscape-phylogeny/)
![View usage-phylogeny on Github](demos/images/usage-phylogeny.gif)

### Create your own stylesheet
[Code](usage-advanced.py) | [Demo](https://dash-gallery.plotly.host/cytoscape-advanced)
![View usage-advanced on Github](demos/images/usage-advanced.gif)

### Use event callbacks
[Code](usage-events.py) | [Demo](https://dash-gallery.plotly.host/cytoscape-events)
![View usage-events on Github](demos/images/usage-events.gif)

### Use external layouts
[Code](demos/usage-elements-extra.py)
![View usage-elements-extra on Github](demos/images/usage-elements-extra.gif)

### Use export graph as image
[Code](demos/usage-image-export.py)
![View usage-image-export on Github](demos/images/usage-image-export.gif)

### Make graph responsive
[Code](demos/usage-responsive-graph.py)
![View usage-responsive-graph on Github](demos/images/usage-responsive-graph.gif)

For an extended gallery, visit the [demos' readme](demos/README.md).
